/*
    SPDX-FileCopyrightText: 2010 Andriy Rysin <rysin@kde.org>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#pragma once

#define KEYBOARD_DBUS_SERVICE_NAME "org.kde.keyboard"
#define KEYBOARD_DBUS_OBJECT_PATH "/Layouts"
#define KEYBOARD_DBUS_CONFIG_RELOAD_MESSAGE "reloadConfig"
